A dataset containing the log of all the bike trips in Milan (using the BikeMi service), in the period from 25th of January to the 6th of March from Duomo to Duomo.
bike_logA list of 41 observed days, each containing a list of 2 components: one which indicates the number of bike trips starting from Duomo at hour t and the other about the number of trips ending in Duomo at time t. Therefore each component is made up by 90 time steps, ranging from 7.00 A.M. to 1.00 A.M. Therefore each component is made up by 90 time steps, ranging from 7.00 A.M. to 1.00 A.M.
number of departing trips from Duomo
number of ending trips in Duomo